@@ -21,15 +21,62 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "rygel-icon-info.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define RYGEL_TYPE_ICON_INFO (rygel_icon_info_get_type ())
+#define RYGEL_ICON_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_ICON_INFO, RygelIconInfo))
+#define RYGEL_ICON_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TYPE_ICON_INFO, RygelIconInfoClass))
+#define RYGEL_IS_ICON_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_ICON_INFO))
+#define RYGEL_IS_ICON_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TYPE_ICON_INFO))
+#define RYGEL_ICON_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TYPE_ICON_INFO, RygelIconInfoClass))
+
+typedef struct _RygelIconInfo RygelIconInfo;
+typedef struct _RygelIconInfoClass RygelIconInfoClass;
+typedef struct _RygelIconInfoPrivate RygelIconInfoPrivate;
+typedef struct _RygelParamSpecIconInfo RygelParamSpecIconInfo;
+
+/**
+ * Holds information about an icon.
+ */
+struct _RygelIconInfo {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	RygelIconInfoPrivate * priv;
+	char* mimetype;
+	guint width;
+	guint height;
+	guint depth;
+	char* path;
+};
+
+struct _RygelIconInfoClass {
+	GTypeClass parent_class;
+	void (*finalize) (RygelIconInfo *self);
+};
+
+struct _RygelParamSpecIconInfo {
+	GParamSpec parent_instance;
+};
 
 
+
+gpointer rygel_icon_info_ref (gpointer instance);
+void rygel_icon_info_unref (gpointer instance);
+GParamSpec* rygel_param_spec_icon_info (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void rygel_value_set_icon_info (GValue* value, gpointer v_object);
+gpointer rygel_value_get_icon_info (const GValue* value);
+GType rygel_icon_info_get_type (void);
 enum  {
 	RYGEL_ICON_INFO_DUMMY_PROPERTY
 };
+RygelIconInfo* rygel_icon_info_new (const char* mimetype, guint width, guint height, guint depth, const char* path);
+RygelIconInfo* rygel_icon_info_construct (GType object_type, const char* mimetype, guint width, guint height, guint depth, const char* path);
+RygelIconInfo* rygel_icon_info_new (const char* mimetype, guint width, guint height, guint depth, const char* path);
 static gpointer rygel_icon_info_parent_class = NULL;
 static void rygel_icon_info_finalize (RygelIconInfo* obj);
 
@@ -37,22 +84,22 @@ static void rygel_icon_info_finalize (RygelIconInfo* obj);
 
 RygelIconInfo* rygel_icon_info_construct (GType object_type, const char* mimetype, guint width, guint height, guint depth, const char* path) {
 	RygelIconInfo* self;
-	char* _tmp1;
-	const char* _tmp0;
-	char* _tmp3;
-	const char* _tmp2;
+	char* _tmp1_;
+	const char* _tmp0_;
+	char* _tmp3_;
+	const char* _tmp2_;
 	g_return_val_if_fail (mimetype != NULL, NULL);
 	g_return_val_if_fail (path != NULL, NULL);
 	self = (RygelIconInfo*) g_type_create_instance (object_type);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->mimetype = (_tmp1 = (_tmp0 = mimetype, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->mimetype = (g_free (self->mimetype), NULL), _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->mimetype = (_tmp1_ = (_tmp0_ = mimetype, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->mimetype = (g_free (self->mimetype), NULL), _tmp1_);
 	self->width = width;
 	self->height = height;
 	self->depth = depth;
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	self->path = (_tmp3 = (_tmp2 = path, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), self->path = (g_free (self->path), NULL), _tmp3);
+	_tmp3_ = NULL;
+	_tmp2_ = NULL;
+	self->path = (_tmp3_ = (_tmp2_ = path, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), self->path = (g_free (self->path), NULL), _tmp3_);
 	return self;
 }
 
