@@ -22,43 +22,125 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "rygel-live-response.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <gio/gio.h>
+#include <libsoup/soup.h>
+#include <gst/gst.h>
+#include <stdlib.h>
+#include <string.h>
 
 
+#define RYGEL_TYPE_STATE_MACHINE (rygel_state_machine_get_type ())
+#define RYGEL_STATE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_STATE_MACHINE, RygelStateMachine))
+#define RYGEL_IS_STATE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_STATE_MACHINE))
+#define RYGEL_STATE_MACHINE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), RYGEL_TYPE_STATE_MACHINE, RygelStateMachineIface))
 
+typedef struct _RygelStateMachine RygelStateMachine;
+typedef struct _RygelStateMachineIface RygelStateMachineIface;
+
+#define RYGEL_TYPE_HTTP_RESPONSE (rygel_http_response_get_type ())
+#define RYGEL_HTTP_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_HTTP_RESPONSE, RygelHTTPResponse))
+#define RYGEL_HTTP_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TYPE_HTTP_RESPONSE, RygelHTTPResponseClass))
+#define RYGEL_IS_HTTP_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_HTTP_RESPONSE))
+#define RYGEL_IS_HTTP_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TYPE_HTTP_RESPONSE))
+#define RYGEL_HTTP_RESPONSE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TYPE_HTTP_RESPONSE, RygelHTTPResponseClass))
+
+typedef struct _RygelHTTPResponse RygelHTTPResponse;
+typedef struct _RygelHTTPResponseClass RygelHTTPResponseClass;
+typedef struct _RygelHTTPResponsePrivate RygelHTTPResponsePrivate;
+
+#define RYGEL_TYPE_LIVE_RESPONSE (rygel_live_response_get_type ())
+#define RYGEL_LIVE_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_LIVE_RESPONSE, RygelLiveResponse))
+#define RYGEL_LIVE_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TYPE_LIVE_RESPONSE, RygelLiveResponseClass))
+#define RYGEL_IS_LIVE_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_LIVE_RESPONSE))
+#define RYGEL_IS_LIVE_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TYPE_LIVE_RESPONSE))
+#define RYGEL_LIVE_RESPONSE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TYPE_LIVE_RESPONSE, RygelLiveResponseClass))
+
+typedef struct _RygelLiveResponse RygelLiveResponse;
+typedef struct _RygelLiveResponseClass RygelLiveResponseClass;
+typedef struct _RygelLiveResponsePrivate RygelLiveResponsePrivate;
+
+typedef enum  {
+	RYGEL_LIVE_RESPONSE_ERROR_MISSING_PLUGIN,
+	RYGEL_LIVE_RESPONSE_ERROR_LINK
+} RygelLiveResponseError;
+#define RYGEL_LIVE_RESPONSE_ERROR rygel_live_response_error_quark ()
+/**
+ * StateMachine interface.
+ */
+struct _RygelStateMachineIface {
+	GTypeInterface parent_iface;
+	void (*run) (RygelStateMachine* self, GCancellable* cancellable);
+};
+
+struct _RygelHTTPResponse {
+	GObject parent_instance;
+	RygelHTTPResponsePrivate * priv;
+	SoupMessage* msg;
+	GCancellable* cancellable;
+};
+
+struct _RygelHTTPResponseClass {
+	GObjectClass parent_class;
+	void (*run) (RygelHTTPResponse* self, GCancellable* cancellable);
+	void (*end) (RygelHTTPResponse* self, gboolean aborted, guint status);
+};
+
+struct _RygelLiveResponse {
+	RygelHTTPResponse parent_instance;
+	RygelLiveResponsePrivate * priv;
+};
+
+struct _RygelLiveResponseClass {
+	RygelHTTPResponseClass parent_class;
+};
 
-static gboolean string_contains (const char* self, const char* needle);
 struct _RygelLiveResponsePrivate {
 	GstPipeline* pipeline;
 	GAsyncQueue* buffers;
 };
 
+
+
+GQuark rygel_live_response_error_quark (void);
+GType rygel_state_machine_get_type (void);
+GType rygel_http_response_get_type (void);
+GType rygel_live_response_get_type (void);
 #define RYGEL_LIVE_RESPONSE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), RYGEL_TYPE_LIVE_RESPONSE, RygelLiveResponsePrivate))
 enum  {
 	RYGEL_LIVE_RESPONSE_DUMMY_PROPERTY
 };
 #define RYGEL_LIVE_RESPONSE_SINK_NAME "fakesink"
+RygelHTTPResponse* rygel_http_response_new (SoupServer* server, SoupMessage* msg, gboolean partial);
+RygelHTTPResponse* rygel_http_response_construct (GType object_type, SoupServer* server, SoupMessage* msg, gboolean partial);
+static void rygel_live_response_prepare_pipeline (RygelLiveResponse* self, const char* name, GstElement* src, GError** error);
+RygelLiveResponse* rygel_live_response_new (SoupServer* server, SoupMessage* msg, const char* name, GstElement* src, GError** error);
+RygelLiveResponse* rygel_live_response_construct (GType object_type, SoupServer* server, SoupMessage* msg, const char* name, GstElement* src, GError** error);
+RygelLiveResponse* rygel_live_response_new (SoupServer* server, SoupMessage* msg, const char* name, GstElement* src, GError** error);
+void rygel_http_response_run (RygelHTTPResponse* self, GCancellable* cancellable);
 static void rygel_live_response_real_run (RygelHTTPResponse* base, GCancellable* cancellable);
+void rygel_http_response_end (RygelHTTPResponse* self, gboolean aborted, guint status);
 static void rygel_live_response_real_end (RygelHTTPResponse* base, gboolean aborted, guint status);
 static inline void _dynamic_set_signal_handoffs1 (GstElement* obj, gboolean value);
+static void rygel_live_response_on_new_buffer (RygelLiveResponse* self, GstElement* sink, GstBuffer* buffer, GstPad* pad);
 static void _rygel_live_response_on_new_buffer_dynamic_handoff0_ (GstElement* _sender, GstBuffer* buffer, GstPad* pad, gpointer self);
 void _dynamic_handoff1_connect (gpointer obj, const char * signal_name, GCallback handler, gpointer data);
-static void _rygel_live_response_src_pad_added_gst_element_pad_added (GstElement* _sender, GstPad* pad, gpointer self);
-static gboolean _rygel_live_response_bus_handler_gst_bus_func (GstBus* bus, GstMessage* message, gpointer self);
-static void rygel_live_response_prepare_pipeline (RygelLiveResponse* self, const char* name, GstElement* src, GError** error);
 static void rygel_live_response_src_pad_added (RygelLiveResponse* self, GstElement* src, GstPad* src_pad);
-static gboolean rygel_live_response_need_rtp_depayloader (RygelLiveResponse* self, GstCaps* caps);
-static gboolean _rygel_live_response_rtp_depay_filter_gst_plugin_feature_filter (GstPluginFeature* feature, gpointer self);
-static void _g_list_free_gst_object_unref (GList* self);
-static GstElement* rygel_live_response_get_rtp_depayloader (RygelLiveResponse* self, GstCaps* caps);
-static gint _rygel_live_response_compare_factories_gcompare_func (void* a, void* b);
-static GstElement* rygel_live_response_get_best_depay (RygelLiveResponse* self, GList* features, GstCaps* caps);
-static gboolean rygel_live_response_rtp_depay_filter (RygelLiveResponse* self, GstPluginFeature* feature);
-static gint rygel_live_response_compare_factories (void* a, void* b);
-static gboolean _rygel_live_response_idle_handler_gsource_func (gpointer self);
-static void rygel_live_response_on_new_buffer (RygelLiveResponse* self, GstElement* sink, GstBuffer* buffer, GstPad* pad);
-static gboolean rygel_live_response_idle_handler (RygelLiveResponse* self);
+static void _rygel_live_response_src_pad_added_gst_element_pad_added (GstElement* _sender, GstPad* pad, gpointer self);
 static gboolean rygel_live_response_bus_handler (RygelLiveResponse* self, GstBus* bus, GstMessage* message);
+static gboolean _rygel_live_response_bus_handler_gst_bus_func (GstBus* bus, GstMessage* message, gpointer self);
+static GstElement* rygel_live_response_get_rtp_depayloader (RygelLiveResponse* self, GstCaps* caps);
+static gboolean rygel_live_response_need_rtp_depayloader (RygelLiveResponse* self, GstCaps* caps);
+static gboolean rygel_live_response_rtp_depay_filter (RygelLiveResponse* self, GstPluginFeature* feature);
+static gboolean _rygel_live_response_rtp_depay_filter_gst_plugin_feature_filter (GstPluginFeature* feature, gpointer self);
+static GstElement* rygel_live_response_get_best_depay (RygelLiveResponse* self, GList* features, GstCaps* caps);
+static void _g_list_free_gst_object_unref (GList* self);
+static gint rygel_live_response_compare_factories (void* a, void* b);
+static gint _rygel_live_response_compare_factories_gcompare_func (void* a, void* b);
+static gboolean rygel_live_response_idle_handler (RygelLiveResponse* self);
+static gboolean _rygel_live_response_idle_handler_gsource_func (gpointer self);
+void rygel_http_response_push_data (RygelHTTPResponse* self, void* data, gsize length);
 static gpointer rygel_live_response_parent_class = NULL;
 static void rygel_live_response_finalize (GObject* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -66,34 +148,27 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 static void g_cclosure_user_marshal_VOID__POINTER_OBJECT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
 
-static gboolean string_contains (const char* self, const char* needle) {
-	g_return_val_if_fail (self != NULL, FALSE);
-	g_return_val_if_fail (needle != NULL, FALSE);
-	return strstr (self, needle) != NULL;
-}
-
-
 GQuark rygel_live_response_error_quark (void) {
 	return g_quark_from_static_string ("rygel_live_response_error-quark");
 }
 
 
 RygelLiveResponse* rygel_live_response_construct (GType object_type, SoupServer* server, SoupMessage* msg, const char* name, GstElement* src, GError** error) {
-	GError * inner_error;
+	GError * _inner_error_;
 	RygelLiveResponse * self;
-	GAsyncQueue* _tmp0;
+	GAsyncQueue* _tmp0_;
 	g_return_val_if_fail (server != NULL, NULL);
 	g_return_val_if_fail (msg != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (src != NULL, NULL);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	self = (RygelLiveResponse*) rygel_http_response_construct (object_type, server, msg, FALSE);
-	soup_message_headers_set_encoding (((RygelHTTPResponse*) self)->msg->response_headers, SOUP_ENCODING_CHUNKED);
-	_tmp0 = NULL;
-	self->priv->buffers = (_tmp0 = g_async_queue_new (), (self->priv->buffers == NULL) ? NULL : (self->priv->buffers = (g_async_queue_unref (self->priv->buffers), NULL)), _tmp0);
-	rygel_live_response_prepare_pipeline (self, name, src, &inner_error);
-	if (inner_error != NULL) {
-		g_propagate_error (error, inner_error);
+	soup_message_headers_set_encoding (((RygelHTTPResponse*) self)->msg->response_headers, SOUP_ENCODING_EOF);
+	_tmp0_ = NULL;
+	self->priv->buffers = (_tmp0_ = g_async_queue_new (), (self->priv->buffers == NULL) ? NULL : (self->priv->buffers = (g_async_queue_unref (self->priv->buffers), NULL)), _tmp0_);
+	rygel_live_response_prepare_pipeline (self, name, src, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_propagate_error (error, _inner_error_);
 		return;
 	}
 	return self;
@@ -122,9 +197,9 @@ static void rygel_live_response_real_end (RygelHTTPResponse* base, gboolean abor
 	/* Flush the queue of buffers*/
 	buffer = NULL;
 	do {
-		GstBuffer* _tmp0;
-		_tmp0 = NULL;
-		buffer = (_tmp0 = (GstBuffer*) g_async_queue_try_pop (self->priv->buffers), (buffer == NULL) ? NULL : (buffer = (gst_buffer_unref (buffer), NULL)), _tmp0);
+		GstBuffer* _tmp0_;
+		_tmp0_ = NULL;
+		buffer = (_tmp0_ = (GstBuffer*) g_async_queue_try_pop (self->priv->buffers), (buffer == NULL) ? NULL : (buffer = (gst_buffer_unref (buffer), NULL)), _tmp0_);
 	} while (buffer != NULL);
 	if (!aborted) {
 		soup_message_body_complete (((RygelHTTPResponse*) self)->msg->response_body);
@@ -160,42 +235,42 @@ static gboolean _rygel_live_response_bus_handler_gst_bus_func (GstBus* bus, GstM
 
 
 static void rygel_live_response_prepare_pipeline (RygelLiveResponse* self, const char* name, GstElement* src, GError** error) {
-	GError * inner_error;
+	GError * _inner_error_;
 	GstElement* sink;
-	GstPipeline* _tmp0;
-	GstElement* _tmp2;
-	GstElement* _tmp1;
+	GstPipeline* _tmp0_;
+	GstElement* _tmp2_;
+	GstElement* _tmp1_;
 	GstBus* bus;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (src != NULL);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	sink = gst_element_factory_make ("fakesink", RYGEL_LIVE_RESPONSE_SINK_NAME);
 	if (sink == NULL) {
-		inner_error = g_error_new_literal (RYGEL_LIVE_RESPONSE_ERROR, RYGEL_LIVE_RESPONSE_ERROR_MISSING_PLUGIN, "Required plugin 'fakesink' missing");
-		if (inner_error != NULL) {
-			g_propagate_error (error, inner_error);
+		_inner_error_ = g_error_new_literal (RYGEL_LIVE_RESPONSE_ERROR, RYGEL_LIVE_RESPONSE_ERROR_MISSING_PLUGIN, "Required plugin 'fakesink' missing");
+		if (_inner_error_ != NULL) {
+			g_propagate_error (error, _inner_error_);
 			(sink == NULL) ? NULL : (sink = (gst_object_unref (sink), NULL));
 			return;
 		}
 	}
 	_dynamic_set_signal_handoffs1 (sink, TRUE);
 	_dynamic_handoff1_connect (sink, "handoff", (GCallback) _rygel_live_response_on_new_buffer_dynamic_handoff0_, self);
-	_tmp0 = NULL;
-	self->priv->pipeline = (_tmp0 = (GstPipeline*) gst_pipeline_new (name), (self->priv->pipeline == NULL) ? NULL : (self->priv->pipeline = (gst_object_unref (self->priv->pipeline), NULL)), _tmp0);
+	_tmp0_ = NULL;
+	self->priv->pipeline = (_tmp0_ = (GstPipeline*) gst_pipeline_new (name), (self->priv->pipeline == NULL) ? NULL : (self->priv->pipeline = (gst_object_unref (self->priv->pipeline), NULL)), _tmp0_);
 	g_assert (self->priv->pipeline != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	gst_bin_add_many ((GstBin*) self->priv->pipeline, (_tmp1 = src, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)), (_tmp2 = sink, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)), NULL);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	gst_bin_add_many ((GstBin*) self->priv->pipeline, (_tmp1_ = src, (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_)), (_tmp2_ = sink, (_tmp2_ == NULL) ? NULL : gst_object_ref (_tmp2_)), NULL);
 	if (src->numpads == 0) {
 		/* Seems source uses dynamic pads, link when pad available*/
 		g_signal_connect_object (src, "pad-added", (GCallback) _rygel_live_response_src_pad_added_gst_element_pad_added, self, 0);
 	} else {
 		/* static pads? easy!*/
 		if (!gst_element_link (src, sink)) {
-			inner_error = g_error_new (RYGEL_LIVE_RESPONSE_ERROR, RYGEL_LIVE_RESPONSE_ERROR_LINK, "Failed to link %s to %s", gst_object_get_name ((GstObject*) src), gst_object_get_name ((GstObject*) sink));
-			if (inner_error != NULL) {
-				g_propagate_error (error, inner_error);
+			_inner_error_ = g_error_new (RYGEL_LIVE_RESPONSE_ERROR, RYGEL_LIVE_RESPONSE_ERROR_LINK, "Failed to link %s to %s", gst_object_get_name ((GstObject*) src), gst_object_get_name ((GstObject*) sink));
+			if (_inner_error_ != NULL) {
+				g_propagate_error (error, _inner_error_);
 				(sink == NULL) ? NULL : (sink = (gst_object_unref (sink), NULL));
 				return;
 			}
@@ -222,11 +297,11 @@ static void rygel_live_response_src_pad_added (RygelLiveResponse* self, GstEleme
 	sink_pad = NULL;
 	depay = rygel_live_response_get_rtp_depayloader (self, caps);
 	if (depay != NULL) {
-		GstElement* _tmp0;
-		GstPad* _tmp2;
-		GstPad* _tmp1;
-		_tmp0 = NULL;
-		gst_bin_add ((GstBin*) self->priv->pipeline, (_tmp0 = depay, (_tmp0 == NULL) ? NULL : gst_object_ref (_tmp0)));
+		GstElement* _tmp0_;
+		GstPad* _tmp2_;
+		GstPad* _tmp1_;
+		_tmp0_ = NULL;
+		gst_bin_add ((GstBin*) self->priv->pipeline, (_tmp0_ = depay, (_tmp0_ == NULL) ? NULL : gst_object_ref (_tmp0_)));
 		if (!gst_element_link (depay, sink)) {
 			g_critical ("rygel-live-response.vala:122: Failed to link %s to %s", gst_object_get_name ((GstObject*) depay), gst_object_get_name ((GstObject*) sink));
 			rygel_http_response_end ((RygelHTTPResponse*) self, FALSE, (guint) SOUP_STATUS_NONE);
@@ -236,15 +311,15 @@ static void rygel_live_response_src_pad_added (RygelLiveResponse* self, GstEleme
 			(depay == NULL) ? NULL : (depay = (gst_object_unref (depay), NULL));
 			return;
 		}
-		_tmp2 = NULL;
-		_tmp1 = NULL;
-		sink_pad = (_tmp2 = (_tmp1 = gst_element_get_compatible_pad (depay, src_pad, caps), (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)), (sink_pad == NULL) ? NULL : (sink_pad = (gst_object_unref (sink_pad), NULL)), _tmp2);
+		_tmp2_ = NULL;
+		_tmp1_ = NULL;
+		sink_pad = (_tmp2_ = (_tmp1_ = gst_element_get_compatible_pad (depay, src_pad, caps), (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_)), (sink_pad == NULL) ? NULL : (sink_pad = (gst_object_unref (sink_pad), NULL)), _tmp2_);
 	} else {
-		GstPad* _tmp4;
-		GstPad* _tmp3;
-		_tmp4 = NULL;
-		_tmp3 = NULL;
-		sink_pad = (_tmp4 = (_tmp3 = gst_element_get_compatible_pad (sink, src_pad, caps), (_tmp3 == NULL) ? NULL : gst_object_ref (_tmp3)), (sink_pad == NULL) ? NULL : (sink_pad = (gst_object_unref (sink_pad), NULL)), _tmp4);
+		GstPad* _tmp4_;
+		GstPad* _tmp3_;
+		_tmp4_ = NULL;
+		_tmp3_ = NULL;
+		sink_pad = (_tmp4_ = (_tmp3_ = gst_element_get_compatible_pad (sink, src_pad, caps), (_tmp3_ == NULL) ? NULL : gst_object_ref (_tmp3_)), (sink_pad == NULL) ? NULL : (sink_pad = (gst_object_unref (sink_pad), NULL)), _tmp4_);
 	}
 	if (gst_pad_link (src_pad, sink_pad) != GST_PAD_LINK_OK) {
 		g_critical ("rygel-live-response.vala:135: Failed to link pad %s to %s", gst_object_get_name ((GstObject*) src_pad), gst_object_get_name ((GstObject*) sink_pad));
@@ -266,14 +341,14 @@ static void rygel_live_response_src_pad_added (RygelLiveResponse* self, GstEleme
 
 
 static gboolean rygel_live_response_need_rtp_depayloader (RygelLiveResponse* self, GstCaps* caps) {
-	const GstStructure* _tmp0;
+	const GstStructure* _tmp0_;
 	GstStructure* structure;
-	gboolean _tmp1;
+	gboolean _tmp1_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (caps != NULL, FALSE);
-	_tmp0 = NULL;
-	structure = (_tmp0 = gst_caps_get_structure (caps, (guint) 0), (_tmp0 == NULL) ? NULL : gst_structure_copy (_tmp0));
-	return (_tmp1 = _vala_strcmp0 (gst_structure_get_name (structure), "application/x-rtp") == 0, (structure == NULL) ? NULL : (structure = (gst_structure_free (structure), NULL)), _tmp1);
+	_tmp0_ = NULL;
+	structure = (_tmp0_ = gst_caps_get_structure (caps, (guint) 0), (_tmp0_ == NULL) ? NULL : gst_structure_copy (_tmp0_));
+	return (_tmp1_ = _vala_strcmp0 (gst_structure_get_name (structure), "application/x-rtp") == 0, (structure == NULL) ? NULL : (structure = (gst_structure_free (structure), NULL)), _tmp1_);
 }
 
 
@@ -291,7 +366,7 @@ static void _g_list_free_gst_object_unref (GList* self) {
 static GstElement* rygel_live_response_get_rtp_depayloader (RygelLiveResponse* self, GstCaps* caps) {
 	GstRegistry* registry;
 	GList* features;
-	GstElement* _tmp1;
+	GstElement* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (caps != NULL, NULL);
 	if (!rygel_live_response_need_rtp_depayloader (self, caps)) {
@@ -299,8 +374,8 @@ static GstElement* rygel_live_response_get_rtp_depayloader (RygelLiveResponse* s
 	}
 	registry = gst_registry_get_default ();
 	features = gst_registry_feature_filter (registry, _rygel_live_response_rtp_depay_filter_gst_plugin_feature_filter, FALSE, self);
-	_tmp1 = NULL;
-	return (_tmp1 = rygel_live_response_get_best_depay (self, features, caps), (features == NULL) ? NULL : (features = (_g_list_free_gst_object_unref (features), NULL)), _tmp1);
+	_tmp1_ = NULL;
+	return (_tmp1_ = rygel_live_response_get_best_depay (self, features, caps), (features == NULL) ? NULL : (features = (_g_list_free_gst_object_unref (features), NULL)), _tmp1_);
 }
 
 
@@ -311,11 +386,10 @@ static gint _rygel_live_response_compare_factories_gcompare_func (void* a, void*
 
 static GstElement* rygel_live_response_get_best_depay (RygelLiveResponse* self, GList* features, GstCaps* caps) {
 	GList* relevant_factories;
-	GstElementFactory* _tmp4;
+	GstElementFactory* _tmp4_;
 	GstElementFactory* factory;
-	GstElement* _tmp5;
+	GstElement* _tmp5_;
 	g_return_val_if_fail (self != NULL, NULL);
-	g_return_val_if_fail (features != NULL, NULL);
 	g_return_val_if_fail (caps != NULL, NULL);
 	relevant_factories = NULL;
 	/* First construct a list of relevant factories*/
@@ -324,19 +398,19 @@ static GstElement* rygel_live_response_get_best_depay (RygelLiveResponse* self,
 		GList* feature_it;
 		feature_collection = features;
 		for (feature_it = feature_collection; feature_it != NULL; feature_it = feature_it->next) {
-			GstPluginFeature* _tmp2;
+			GstPluginFeature* _tmp2_;
 			GstPluginFeature* feature;
-			_tmp2 = NULL;
-			feature = (_tmp2 = (GstPluginFeature*) feature_it->data, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2));
+			_tmp2_ = NULL;
+			feature = (_tmp2_ = (GstPluginFeature*) feature_it->data, (_tmp2_ == NULL) ? NULL : gst_object_ref (_tmp2_));
 			{
-				GstElementFactory* _tmp0;
+				GstElementFactory* _tmp0_;
 				GstElementFactory* factory;
-				_tmp0 = NULL;
-				factory = (_tmp0 = GST_ELEMENT_FACTORY (feature), (_tmp0 == NULL) ? NULL : gst_object_ref (_tmp0));
+				_tmp0_ = NULL;
+				factory = (_tmp0_ = GST_ELEMENT_FACTORY (feature), (_tmp0_ == NULL) ? NULL : gst_object_ref (_tmp0_));
 				if (gst_element_factory_can_sink_caps (factory, caps)) {
-					GstElementFactory* _tmp1;
-					_tmp1 = NULL;
-					relevant_factories = g_list_append (relevant_factories, (_tmp1 = factory, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
+					GstElementFactory* _tmp1_;
+					_tmp1_ = NULL;
+					relevant_factories = g_list_append (relevant_factories, (_tmp1_ = factory, (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_)));
 				}
 				(feature == NULL) ? NULL : (feature = (gst_object_unref (feature), NULL));
 				(factory == NULL) ? NULL : (factory = (gst_object_unref (factory), NULL));
@@ -344,47 +418,54 @@ static GstElement* rygel_live_response_get_best_depay (RygelLiveResponse* self,
 		}
 	}
 	if (g_list_length (relevant_factories) == 0) {
-		GstElement* _tmp3;
+		GstElement* _tmp3_;
 		/* No relevant factory available, hence no depayloader*/
-		_tmp3 = NULL;
-		return (_tmp3 = NULL, (relevant_factories == NULL) ? NULL : (relevant_factories = (_g_list_free_gst_object_unref (relevant_factories), NULL)), _tmp3);
+		_tmp3_ = NULL;
+		return (_tmp3_ = NULL, (relevant_factories == NULL) ? NULL : (relevant_factories = (_g_list_free_gst_object_unref (relevant_factories), NULL)), _tmp3_);
 	}
 	/* Then sort the list through their ranks*/
 	relevant_factories = g_list_sort (relevant_factories, _rygel_live_response_compare_factories_gcompare_func);
 	/* create an element of the top ranking factory and return it*/
-	_tmp4 = NULL;
-	factory = (_tmp4 = (GstElementFactory*) relevant_factories->data, (_tmp4 == NULL) ? NULL : gst_object_ref (_tmp4));
-	_tmp5 = NULL;
-	return (_tmp5 = gst_element_factory_make (gst_plugin_feature_get_name ((GstPluginFeature*) factory), NULL), (relevant_factories == NULL) ? NULL : (relevant_factories = (_g_list_free_gst_object_unref (relevant_factories), NULL)), (factory == NULL) ? NULL : (factory = (gst_object_unref (factory), NULL)), _tmp5);
+	_tmp4_ = NULL;
+	factory = (_tmp4_ = (GstElementFactory*) relevant_factories->data, (_tmp4_ == NULL) ? NULL : gst_object_ref (_tmp4_));
+	_tmp5_ = NULL;
+	return (_tmp5_ = gst_element_factory_make (gst_plugin_feature_get_name ((GstPluginFeature*) factory), NULL), (relevant_factories == NULL) ? NULL : (relevant_factories = (_g_list_free_gst_object_unref (relevant_factories), NULL)), (factory == NULL) ? NULL : (factory = (gst_object_unref (factory), NULL)), _tmp5_);
+}
+
+
+static gboolean string_contains (const char* self, const char* needle) {
+	g_return_val_if_fail (self != NULL, FALSE);
+	g_return_val_if_fail (needle != NULL, FALSE);
+	return strstr (self, needle) != NULL;
 }
 
 
 static gboolean rygel_live_response_rtp_depay_filter (RygelLiveResponse* self, GstPluginFeature* feature) {
-	GstElementFactory* _tmp1;
+	GstElementFactory* _tmp1_;
 	GstElementFactory* factory;
-	gboolean _tmp2;
+	gboolean _tmp2_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (feature != NULL, FALSE);
 	if (!g_type_is_a (G_TYPE_FROM_INSTANCE ((GObject*) feature), GST_TYPE_ELEMENT_FACTORY)) {
 		return FALSE;
 	}
-	_tmp1 = NULL;
-	factory = (_tmp1 = GST_ELEMENT_FACTORY (feature), (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1));
-	return (_tmp2 = string_contains (gst_element_factory_get_klass (factory), "Depayloader"), (factory == NULL) ? NULL : (factory = (gst_object_unref (factory), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	factory = (_tmp1_ = GST_ELEMENT_FACTORY (feature), (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_));
+	return (_tmp2_ = string_contains (gst_element_factory_get_klass (factory), "Depayloader"), (factory == NULL) ? NULL : (factory = (gst_object_unref (factory), NULL)), _tmp2_);
 }
 
 
 static gint rygel_live_response_compare_factories (void* a, void* b) {
-	GstElementFactory* _tmp0;
+	GstElementFactory* _tmp0_;
 	GstElementFactory* factory_a;
-	GstElementFactory* _tmp1;
+	GstElementFactory* _tmp1_;
 	GstElementFactory* factory_b;
-	gint _tmp2;
-	_tmp0 = NULL;
-	factory_a = (_tmp0 = GST_ELEMENT_FACTORY (a), (_tmp0 == NULL) ? NULL : gst_object_ref (_tmp0));
-	_tmp1 = NULL;
-	factory_b = (_tmp1 = GST_ELEMENT_FACTORY (b), (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1));
-	return (_tmp2 = (gint) (gst_plugin_feature_get_rank ((GstPluginFeature*) factory_b) - gst_plugin_feature_get_rank ((GstPluginFeature*) factory_a)), (factory_a == NULL) ? NULL : (factory_a = (gst_object_unref (factory_a), NULL)), (factory_b == NULL) ? NULL : (factory_b = (gst_object_unref (factory_b), NULL)), _tmp2);
+	gint _tmp2_;
+	_tmp0_ = NULL;
+	factory_a = (_tmp0_ = GST_ELEMENT_FACTORY (a), (_tmp0_ == NULL) ? NULL : gst_object_ref (_tmp0_));
+	_tmp1_ = NULL;
+	factory_b = (_tmp1_ = GST_ELEMENT_FACTORY (b), (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_));
+	return (_tmp2_ = (gint) (gst_plugin_feature_get_rank ((GstPluginFeature*) factory_b) - gst_plugin_feature_get_rank ((GstPluginFeature*) factory_a)), (factory_a == NULL) ? NULL : (factory_a = (gst_object_unref (factory_a), NULL)), (factory_b == NULL) ? NULL : (factory_b = (gst_object_unref (factory_b), NULL)), _tmp2_);
 }
 
 
@@ -394,26 +475,26 @@ static gboolean _rygel_live_response_idle_handler_gsource_func (gpointer self) {
 
 
 static void rygel_live_response_on_new_buffer (RygelLiveResponse* self, GstElement* sink, GstBuffer* buffer, GstPad* pad) {
-	GstBuffer* _tmp0;
+	GstBuffer* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (sink != NULL);
 	g_return_if_fail (buffer != NULL);
 	g_return_if_fail (pad != NULL);
-	_tmp0 = NULL;
-	g_async_queue_push (self->priv->buffers, (_tmp0 = buffer, (_tmp0 == NULL) ? NULL : gst_buffer_ref (_tmp0)));
+	_tmp0_ = NULL;
+	g_async_queue_push (self->priv->buffers, (_tmp0_ = buffer, (_tmp0_ == NULL) ? NULL : gst_buffer_ref (_tmp0_)));
 	g_idle_add_full (G_PRIORITY_HIGH_IDLE, _rygel_live_response_idle_handler_gsource_func, g_object_ref (self), g_object_unref);
 }
 
 
 static gboolean rygel_live_response_idle_handler (RygelLiveResponse* self) {
 	GstBuffer* buffer;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	buffer = (GstBuffer*) g_async_queue_try_pop (self->priv->buffers);
 	if (buffer != NULL) {
 		rygel_http_response_push_data ((RygelHTTPResponse*) self, buffer->data, (gsize) buffer->size);
 	}
-	return (_tmp0 = FALSE, (buffer == NULL) ? NULL : (buffer = (gst_buffer_unref (buffer), NULL)), _tmp0);
+	return (_tmp0_ = FALSE, (buffer == NULL) ? NULL : (buffer = (gst_buffer_unref (buffer), NULL)), _tmp0_);
 }
 
 
@@ -431,30 +512,30 @@ static gboolean rygel_live_response_bus_handler (RygelLiveResponse* self, GstBus
 		err = NULL;
 		err_msg = NULL;
 		if (message->type == GST_MESSAGE_ERROR) {
-			char* _tmp3;
-			char* _tmp2;
-			GError* _tmp1;
-			GError* _tmp0;
-			_tmp3 = NULL;
-			_tmp2 = NULL;
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			(gst_message_parse_error (message, &_tmp0, &_tmp2), err = (_tmp1 = _tmp0, (err == NULL) ? NULL : (err = (g_error_free (err), NULL)), _tmp1));
-			err_msg = (_tmp3 = _tmp2, err_msg = (g_free (err_msg), NULL), _tmp3);
+			char* _tmp3_;
+			char* _tmp2_;
+			GError* _tmp1_;
+			GError* _tmp0_;
+			_tmp3_ = NULL;
+			_tmp2_ = NULL;
+			_tmp1_ = NULL;
+			_tmp0_ = NULL;
+			(gst_message_parse_error (message, &_tmp0_, &_tmp2_), err = (_tmp1_ = _tmp0_, (err == NULL) ? NULL : (err = (g_error_free (err), NULL)), _tmp1_));
+			err_msg = (_tmp3_ = _tmp2_, err_msg = (g_free (err_msg), NULL), _tmp3_);
 			g_critical ("rygel-live-response.vala:235: Error from pipeline %s:%s", gst_object_get_name ((GstObject*) self->priv->pipeline), err_msg);
 			ret = FALSE;
 		} else {
 			if (message->type == GST_MESSAGE_WARNING) {
-				char* _tmp7;
-				char* _tmp6;
-				GError* _tmp5;
-				GError* _tmp4;
-				_tmp7 = NULL;
-				_tmp6 = NULL;
-				_tmp5 = NULL;
-				_tmp4 = NULL;
-				(gst_message_parse_warning (message, &_tmp4, &_tmp6), err = (_tmp5 = _tmp4, (err == NULL) ? NULL : (err = (g_error_free (err), NULL)), _tmp5));
-				err_msg = (_tmp7 = _tmp6, err_msg = (g_free (err_msg), NULL), _tmp7);
+				char* _tmp7_;
+				char* _tmp6_;
+				GError* _tmp5_;
+				GError* _tmp4_;
+				_tmp7_ = NULL;
+				_tmp6_ = NULL;
+				_tmp5_ = NULL;
+				_tmp4_ = NULL;
+				(gst_message_parse_warning (message, &_tmp4_, &_tmp6_), err = (_tmp5_ = _tmp4_, (err == NULL) ? NULL : (err = (g_error_free (err), NULL)), _tmp5_));
+				err_msg = (_tmp7_ = _tmp6_, err_msg = (g_free (err_msg), NULL), _tmp7_);
 				g_warning ("rygel-live-response.vala:242: Warning from pipeline %s:%s", gst_object_get_name ((GstObject*) self->priv->pipeline), err_msg);
 			}
 		}
@@ -471,9 +552,9 @@ static gboolean rygel_live_response_bus_handler (RygelLiveResponse* self, GstBus
 static void rygel_live_response_class_init (RygelLiveResponseClass * klass) {
 	rygel_live_response_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (RygelLiveResponsePrivate));
-	G_OBJECT_CLASS (klass)->finalize = rygel_live_response_finalize;
 	RYGEL_HTTP_RESPONSE_CLASS (klass)->run = rygel_live_response_real_run;
 	RYGEL_HTTP_RESPONSE_CLASS (klass)->end = rygel_live_response_real_end;
+	G_OBJECT_CLASS (klass)->finalize = rygel_live_response_finalize;
 }
 
 
