@@ -21,15 +21,62 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "rygel-resource-info.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define RYGEL_TYPE_RESOURCE_INFO (rygel_resource_info_get_type ())
+#define RYGEL_RESOURCE_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_RESOURCE_INFO, RygelResourceInfo))
+#define RYGEL_RESOURCE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TYPE_RESOURCE_INFO, RygelResourceInfoClass))
+#define RYGEL_IS_RESOURCE_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_RESOURCE_INFO))
+#define RYGEL_IS_RESOURCE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TYPE_RESOURCE_INFO))
+#define RYGEL_RESOURCE_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TYPE_RESOURCE_INFO, RygelResourceInfoClass))
+
+typedef struct _RygelResourceInfo RygelResourceInfo;
+typedef struct _RygelResourceInfoClass RygelResourceInfoClass;
+typedef struct _RygelResourceInfoPrivate RygelResourceInfoPrivate;
+typedef struct _RygelParamSpecResourceInfo RygelParamSpecResourceInfo;
+
+/**
+ * Holds information about a particular resource (device and service)
+ * implementation.
+ */
+struct _RygelResourceInfo {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	RygelResourceInfoPrivate * priv;
+	char* upnp_type;
+	char* upnp_id;
+	char* description_path;
+	GType type;
+};
+
+struct _RygelResourceInfoClass {
+	GTypeClass parent_class;
+	void (*finalize) (RygelResourceInfo *self);
+};
+
+struct _RygelParamSpecResourceInfo {
+	GParamSpec parent_instance;
+};
 
 
+
+gpointer rygel_resource_info_ref (gpointer instance);
+void rygel_resource_info_unref (gpointer instance);
+GParamSpec* rygel_param_spec_resource_info (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void rygel_value_set_resource_info (GValue* value, gpointer v_object);
+gpointer rygel_value_get_resource_info (const GValue* value);
+GType rygel_resource_info_get_type (void);
 enum  {
 	RYGEL_RESOURCE_INFO_DUMMY_PROPERTY
 };
+RygelResourceInfo* rygel_resource_info_new (const char* upnp_id, const char* upnp_type, const char* description_path, GType type);
+RygelResourceInfo* rygel_resource_info_construct (GType object_type, const char* upnp_id, const char* upnp_type, const char* description_path, GType type);
+RygelResourceInfo* rygel_resource_info_new (const char* upnp_id, const char* upnp_type, const char* description_path, GType type);
 static gpointer rygel_resource_info_parent_class = NULL;
 static void rygel_resource_info_finalize (RygelResourceInfo* obj);
 
@@ -37,25 +84,25 @@ static void rygel_resource_info_finalize (RygelResourceInfo* obj);
 
 RygelResourceInfo* rygel_resource_info_construct (GType object_type, const char* upnp_id, const char* upnp_type, const char* description_path, GType type) {
 	RygelResourceInfo* self;
-	char* _tmp1;
-	const char* _tmp0;
-	char* _tmp3;
-	const char* _tmp2;
-	char* _tmp5;
-	const char* _tmp4;
+	char* _tmp1_;
+	const char* _tmp0_;
+	char* _tmp3_;
+	const char* _tmp2_;
+	char* _tmp5_;
+	const char* _tmp4_;
 	g_return_val_if_fail (upnp_id != NULL, NULL);
 	g_return_val_if_fail (upnp_type != NULL, NULL);
 	g_return_val_if_fail (description_path != NULL, NULL);
 	self = (RygelResourceInfo*) g_type_create_instance (object_type);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->upnp_type = (_tmp1 = (_tmp0 = upnp_type, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->upnp_type = (g_free (self->upnp_type), NULL), _tmp1);
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	self->upnp_id = (_tmp3 = (_tmp2 = upnp_id, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), self->upnp_id = (g_free (self->upnp_id), NULL), _tmp3);
-	_tmp5 = NULL;
-	_tmp4 = NULL;
-	self->description_path = (_tmp5 = (_tmp4 = description_path, (_tmp4 == NULL) ? NULL : g_strdup (_tmp4)), self->description_path = (g_free (self->description_path), NULL), _tmp5);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->upnp_type = (_tmp1_ = (_tmp0_ = upnp_type, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->upnp_type = (g_free (self->upnp_type), NULL), _tmp1_);
+	_tmp3_ = NULL;
+	_tmp2_ = NULL;
+	self->upnp_id = (_tmp3_ = (_tmp2_ = upnp_id, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), self->upnp_id = (g_free (self->upnp_id), NULL), _tmp3_);
+	_tmp5_ = NULL;
+	_tmp4_ = NULL;
+	self->description_path = (_tmp5_ = (_tmp4_ = description_path, (_tmp4_ == NULL) ? NULL : g_strdup (_tmp4_)), self->description_path = (g_free (self->description_path), NULL), _tmp5_);
 	self->type = type;
 	return self;
 }
